@@ -1,12 +1,12 @@
 //! The command line argument parser for Wright
-use std::env;
+extern crate regex;
+use self::regex::Regex;
 use version;
 
 /// Parse arguments passed to the wright command.
 /// Returns `None` if there is no action to take after parsing arguments.
 /// Otherwise, it will return `Some(file)` where `file` is a String filename to be interpreted.
-pub fn argparse(args: env::Args) -> Option<String> {
-    let all_args : Vec<String> = args.collect();
+pub fn argparse(all_args: Vec<String>) -> Option<String> {
     if all_args.len() == 1 {
         println!("Wright requires a file to interpret.");
         help();
@@ -19,6 +19,13 @@ pub fn argparse(args: env::Args) -> Option<String> {
         version();
         None
     } else if all_args.len() == 2 {
+        let re: Regex = Regex::new(r"[[:alpha:]].wr|[[:alpha:]].wright").unwrap();
+        if !re.is_match(all_args[1].clone().as_str()) {
+            println!("File must end with .wr or .wright. Consider renaming {f} to {f}.wr",
+                f = all_args[0].clone()
+            );
+            return None;
+        }
         Some(all_args[1].clone())
     } else {
         println!("Unrecognized arguments. \n\n");
