@@ -3,4 +3,7 @@ pub mod argparser;
 pub mod run;
 pub mod version;
 pub mod interpreter;
-pub mod lexer;
\ No newline at end of file
+pub mod lexer;
+pub mod position;
+pub mod internals;
+pub mod errors;
\ No newline at end of file
